# flake8: noqa
from miio.airconditioningcompanion import AirConditioningCompanion
from miio.airconditioningcompanion import AirConditioningCompanionV3
from miio.airfresh import AirFresh
from miio.airhumidifier import AirHumidifier
from miio.airdehumidifier import AirDehumidifier
from miio.airpurifier import AirPurifier
from miio.airqualitymonitor import AirQualityMonitor
from miio.ceil import Ceil
from miio.chuangmi_camera import ChuangmiCamera
from miio.chuangmi_ir import ChuangmiIr
from miio.chuangmi_plug import Plug, PlugV1, PlugV3, ChuangmiPlug
from miio.cooker import Cooker
from miio.device import Device, DeviceException, DeviceError
from miio.fan import Fan, FanV2, FanSA1, FanZA1, FanZA4, FanP5
from miio.philips_bulb import PhilipsBulb
from miio.philips_eyecare import PhilipsEyecare
from miio.philips_moonlight import PhilipsMoonlight
from miio.powerstrip import PowerStrip
from miio.protocol import Message, Utils
from miio.toiletlid import Toiletlid
from miio.pwzn_relay import PwznRelay
from miio.vacuum import Vacuum, VacuumException
from miio.vacuumcontainers import (VacuumStatus, ConsumableStatus, DNDStatus,
                                   CleaningDetails, CleaningSummary, Timer, )
from miio.waterpurifier import WaterPurifier
from miio.wifirepeater import WifiRepeater
from miio.wifispeaker import WifiSpeaker
from miio.yeelight import Yeelight
from miio.aqaracamera import AqaraCamera

from miio.discovery import Discovery
